#!/usr/bin/env python
#
#   filter-blob.py
#   zfilenet
#
#   Copyright (C) 2008 Ross Light
#
#   This file is part of zfilenet.
#
#   zfilenet is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   zfilenet is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with zfilenet.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Blob server maintenence script

Removes any blobs not on a whitelist (like one provided by find-blob-list.py).

usage: filter-blob.py database filter_file
"""

import sqlite3
import sys

import progtools

__author__ = 'Ross Light'
__date__ = 'June 15, 2008'
__all__ = ['main']

@progtools.reportexits
def main(args=None):
    if args is None:
        args = sys.argv[1:]
    if len(args) != 2:
        raise progtools.UsageError()
    server_db = sqlite3.connect(args[0])
    filter_file = progtools.open_input_file(args[1])
    # Load blob ID set
    filter_set = set()
    for line in filter_file:
        filter_set.add(line.strip())
    filter_file.close()
    # Filter blobs
    delete_ids = []
    cursor = server_db.cursor()
    cursor.execute("SELECT blob_db_id, blob_uuid FROM data_blobs;")
    for (blob_db_id, blob_uuid) in cursor:
        if blob_uuid not in filter_set:
            delete_ids.append(blob_db_id)
    cursor.executemany("DELETE FROM data_blobs WHERE blob_db_id = ?;",
                       [(delete_id,) for delete_id in delete_ids])
    server_db.commit()
    cursor.execute("VACUUM;")
    server_db.commit()
    print "Pruned %i blob(s)" % len(delete_ids)
    return 0

if __name__ == '__main__':
    sys.exit(main())
